@@ -7,7 +7,7 @@ __author__ = "Anthony Fong"
 __copyright__ = "Copyright 2021, Anthony Fong"
 __credits__ = ["Anthony Fong"]
 __license__ = ""
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Anthony Fong"
 __email__ = ""
 __status__ = "Production/Stable"
@@ -19,6 +19,5 @@ __status__ = "Production/Stable"
 # Local Libraries #
 from .baseobject import BaseObject
 from .basemeta import BaseMeta
-from .initmeta import InitMeta
-from .wrappers import StaticWrapper, DynamicWrapper
+from .objects import *
 from .warnings import TimeoutWarning
