@@ -7,10 +7,10 @@ __author__ = "Anthony Fong"
 __copyright__ = "Copyright 2021, Anthony Fong"
 __credits__ = ["Anthony Fong"]
 __license__ = ""
-__version__ = "1.2.0"
+__version__ = "1.4.0"
 __maintainer__ = "Anthony Fong"
 __email__ = ""
-__status__ = "Prototype"
+__status__ = "Production/Stable"
 
 # Default Libraries #
 
@@ -23,6 +23,9 @@ __status__ = "Prototype"
 # Classes #
 class TimeoutWarning(Warning):
     """A general warning for timeouts."""
+
+    # Magic Methods
+    # Construction/Destruction
     def __init__(self, name="A function"):
         message = f"{name} timed out"
         super().__init__(message)
